Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ParsedArguments ¶
type ParsedArguments struct {
GenerateInterfaceAndShimFromPackageDirectory bool
SourcePackageDir string // abs path to the dir containing the interface to fake
PackagePath string // package path to the package containing the interface to fake
OutputPath string // path to write the fake file to
DestinationPackageName string // often the base-dir for OutputPath but must be a valid package name
InterfaceName string // the interface to counterfeit
FakeImplName string // the name of the struct implementing the given interface
PrintToStdOut bool
GenerateMode bool
Quiet bool
HeaderFile string
}
func (*ParsedArguments) PrettyPrint ¶ added in v6.1.0
func (a *ParsedArguments) PrettyPrint()
Click to show internal directories.
Click to hide internal directories.